==> sumus-6.4.5-sources.jar: io/intino/sumus/graph/Metric.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Metric extends io.intino.sumus.graph.AbstractMetric implements io.intino.tara.magritte.tags.Terminal {



	public Metric(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Metric.Unit> metricUnitList() {
		return new io.intino.tara.magritte.utils.ProxyList<>(unitList, io.intino.sumus.graph.Metric.Unit.class);
	}

	public io.intino.sumus.graph.Metric.Unit metricUnit(int index) {
		return metricUnitList().get(index);
	}

	public java.util.List<io.intino.sumus.graph.Metric.Unit> metricUnitList(java.util.function.Predicate<io.intino.sumus.graph.Metric.Unit> predicate) {
		return metricUnitList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);

	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);

    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.AbstractMetric.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Metric.Unit unit(io.intino.sumus.graph.functions.Converter convert) {
		    io.intino.sumus.graph.Metric.Unit newElement = core$().graph().concept(io.intino.sumus.graph.Metric.Unit.class).createNode(name, core$()).as(io.intino.sumus.graph.Metric.Unit.class);
			newElement.core$().set(newElement, "convert", java.util.Collections.singletonList(convert));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear extends io.intino.sumus.graph.AbstractMetric.Clear {

	}

	public static class Unit extends io.intino.sumus.graph.AbstractMetric.Unit implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.functions.Converter convert;

		public Unit(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public double convert(double value) {
			return convert.convert(value);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("convert", this.convert != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.convert)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("convert")) this.convert = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.Converter.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("convert")) this.convert = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.Converter.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.0.3-sources.jar: io/intino/sumus/graph/Metric.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Metric extends io.intino.sumus.graph.AbstractMetric implements io.intino.tara.magritte.tags.Terminal {



	public Metric(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Metric.Unit> metricUnitList() {
		return new io.intino.tara.magritte.utils.ProxyList<>(unitList, io.intino.sumus.graph.Metric.Unit.class);
	}

	public io.intino.sumus.graph.Metric.Unit metricUnit(int index) {
		return metricUnitList().get(index);
	}

	public java.util.List<io.intino.sumus.graph.Metric.Unit> metricUnitList(java.util.function.Predicate<io.intino.sumus.graph.Metric.Unit> predicate) {
		return metricUnitList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);

	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);

    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.AbstractMetric.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Metric.Unit unit(io.intino.sumus.graph.functions.Converter convert) {
		    io.intino.sumus.graph.Metric.Unit newElement = core$().graph().concept(io.intino.sumus.graph.Metric.Unit.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Metric.Unit.class);
			newElement.core$().set(newElement, "convert", java.util.Collections.singletonList(convert));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear extends io.intino.sumus.graph.AbstractMetric.Clear {

	}

	public static class Unit extends io.intino.sumus.graph.AbstractMetric.Unit implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.functions.Converter convert;

		public Unit(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public double convert(double value) {
			return convert.convert(value);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("convert", this.convert != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.convert)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("convert")) this.convert = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.Converter.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("convert")) this.convert = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.Converter.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
